@@ -10,10 +10,10 @@ inputSample <- function(data) {
   # reorder groups
   data[, 2] <- factor(data[, 2], levels = unique(data[, 2]))
   
-  targets <- data[data[,2] == levels(data[,2])[nlevels(data[,2])],]
+  mixtures <- data[data[,2] == levels(data[,2])[nlevels(data[,2])],]
   
-  rownames(targets) <- NULL
-  samples <- as.data.frame(targets[,-(0:2)])
+  rownames(mixtures) <- NULL
+  samples <- as.data.frame(mixtures[,-(0:2)])
   samples <- round(samples, 2)
   
   id_samples <- c(1:nrow(samples))
